package com.bogotobogo.CListView3;

import android.app.ListActivity;
import android.content.Context;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

/**
 * A list view example where the 
 * data comes from a custom ListAdapter
 */
public class CListView3Activity extends ListActivity 
{
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        // Use our own list adapter
        setListAdapter(new PhoneListAdapter(this));
    }
           
    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {    
       ((PhoneListAdapter)getListAdapter()).toggle(position);
    }
    
    /**
     * A sample ListAdapter that presents content
     * from arrays of phones and text.
     */
    private class PhoneListAdapter extends BaseAdapter {
        public PhoneListAdapter(Context context) {
            mContext = context;
        }

        /**
         * The number of items in the list is determined 
         * by the number of phones in our array.
         */
        public int getCount() {
            return mPhones.length;
        }

        /**
         * Since the data comes from an array, just returning
         * the index is sufficient to get at the data. If we
         * were using a more complex data structure, we
         * would return whatever object represents one 
         * row in the list.
         */
        public Object getItem(int position) {
            return position;
        }

        /**
         * Use the array index as a unique id.
         */
        public long getItemId(int position) {
            return position;
        }

        /**
         * Make a PhoneView to hold each row.
         */
        public View getView(int position, View convertView, ViewGroup parent) {
            PhoneView sv;
            if (convertView == null) {
                sv = new PhoneView
			(mContext, mPhones[position], mDetail[position], mExpanded[position]);
            } else {
                sv = (PhoneView)convertView;
                sv.setName(mPhones[position]);
                sv.setDetail(mDetail[position]);
                sv.setExpanded(mExpanded[position]);
            }
            
            return sv;
        }

        public void toggle(int position) {
            mExpanded[position] = !mExpanded[position];
            notifyDataSetChanged();
        }
        
        /**
         * Remember our context so we can use it when constructing views.
         */
        private Context mContext;
        
        /**
         * Our data for names of phones, part 1.
         */
        private String[] mPhones = 
        {
        		"Samsung Galaxy Nexus ",   
                "Samsung Galaxy S II Skyrocket ",
                "Motorola Droid Razr ",       
                "Apple iPhone 4S ",
                "HTC Rezound "
        };
        
        /**
         * Our data for the detail description of each phone, part 2.
         */
        private String[] mDetail = 
        {
                "The Samsung Galaxy Nexus is a big step forward for Android, " +
                "but it's not the giant leap you may have been expecting." +
                "As impressive as it is, Ice Cream Sandwich can be messy, " +
                "and without it, the Galaxy Nexus is just another Nexus device.",
                
                "If you live in an area that gets AT&T's LTE network, " + 
                "we highly recommend the powerful and beautiful ' +" +
                "Samsung Galaxy S II Skyrocket.",
                
                "With its razor-thin design, jam-packed features, " +
                "and blazing speed, the Motorola Droid Razr is " +
                "easily one of the year's top Android smartphones.",
                
                "The iPhone 4S isn't the king of cell phones, " +
                "but it's part of the royal family nonetheless.' +" +
                "Even without 4G and a giant screen, this phone's smart " +
                "voice assistant, Siri, the benefits of iOS 5, " +
                "and its spectacular camera make it a top choice " +
                "for anyone ready to upgrade.",
                           
                "While it may have a hefty build, the HTC " +
                "Rezound's beautiful display, commendable performance ," +
                "and multimedia-rich features make it a top phone " +
                "for Verizon customers."
        };
        
        /**
         * Our data, part 3.
         */
        private boolean[] mExpanded = 
        {
                false,
                false,
                false,
                false,
                false,
                false,
                false,
                false   
        };
    }
    /**
     * We will use a PhoneView to display each phone. 
     * It's just a LinearLayout with two text fields.
     */
    private class PhoneView extends LinearLayout {
        public PhoneView(Context context, String name, String detail, boolean expanded) {
            super(context);
            
            this.setOrientation(VERTICAL);
            
            // Here we build the child views in code. They could also have
            // been specified in an XML file.
            
            mPhone = new TextView(context);
            mPhone.setText(name);
            addView(mPhone, 
		new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT));
            
            mDetail = new TextView(context);
            mDetail.setText(detail);
            addView(mDetail, 
		new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT));
            
            mDetail.setVisibility(expanded ? VISIBLE : GONE);
        }
        
        /**
         * Convenience method to set the name of a PhoneView
         */
        public void setName(String name) {
            mPhone.setText(name);
        }
        
        /**
         * Convenience method to set the detail of a PhoneView
         */
        public void setDetail(String words) {
            mDetail.setText(words);
        }
        
        /**
         * Convenience method to expand or hide the detail
         */
        public void setExpanded(boolean expanded) {
            mDetail.setVisibility(expanded ? VISIBLE : GONE);
        }
        
        private TextView mPhone;
        private TextView mDetail;
    }
}